View source: R/NNCTFunctions.R
| bvnorm.pdf | R Documentation |
Computes the value of the probability density function (i.e., density) of the bivariate normal distribution
at the specified point X, with mean mu and standard deviations of the first and second components being s_1
and s_2 (denoted as s1 and s2 in the arguments of the function, respectively)
and correlation between them being rho (i.e., the covariance matrix is \Sigma=S where S_{11}=s_1^2,
S_{22}=s_2^2, S_{12}=S_{21}=s_1 s_2 rho).
bvnorm.pdf(X, mu = c(0, 0), s1 = 1, s2 = 1, rho = 0)
X |
A set of 2D points of size |
mu |
A |
s1, s2 |
The standard deviations of the first and second components of the bivariate normal distribution,
with default is |
rho |
The correlation between the first and second components of the bivariate normal distribution with default=0. |
The value of the probability density function (i.e., density) of the bivariate normal distribution
at the specified point X, with mean mu and standard deviations of the first and second components being s_1
and s_2 and correlation between them being rho.
Elvan Ceyhan
mvrnorm
mu<-c(0,0)
s1<-1
s2<-1
rho<-.5
n<-5
Xp<-cbind(runif(n),runif(n))
bvnorm.pdf(Xp,mu,s1,s2,rho)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.