Three functions: var.tctI, var.tctIII, and var.tctIV.
These functions return the variances of \(T_{ij}\) values
for \(i,j=1,\ldots,k\) in the TCT in matrix form which
is of the same dimension as TCT for types I, III and IV tests.
The argument covN must be the covariance
between \(N_{ij}\) values which are obtained
from the NNCT by row-wise vectorization.
These variances are valid under RL or
conditional on \(Q\) and \(R\) under CSR.
See also (ceyhan:jkss-posthoc-2017;textualnnspat).
var.tctI(ct, covN)var.tctIII(ct, covN)
var.tctIV(ct, covN)
Each of these functions returns a matrix of
same dimension as, ct, whose entries are the variances of
the entries in the TCT for the corresponding type of cell-specific test.
The row and column names are inherited from ct.
A nearest neighbor contingency table
The \(k^2 \times k^2\) covariance matrix of
row-wise vectorized cell counts of NNCT, ct.
var.tct and var.nnct