Two functions: Znnself.ct and Znnself.
Both functions are objects of class "cellhtest" but with different arguments (see the parameter list below).
Each one performs hypothesis tests of equality of the expected values of the self entries (i.e., first column)
in a species correspondence contingency table (SCCT) or the expected values of the diagonal entries \(N_{ii}\) in
an NNCT to the ones under RL or CSR.
That is, each performs NN self reflexivity for each class test which is appropriate
(i.e., have the appropriate asymptotic sampling distribution)
for completely mapped data.
NN self reflexivity is for each class can be viewed as a decomposition of species correspondence for
each class.
(See ceyhan:NNCorrespond2018;textualnnspat for more detail).
Each test is based on the normal approximation of the self entries (i.e., first column) in a
species correspondence contingency table (SCCT) or the diagonal entries \(N_{ii}\) in an NNCT and
are due to ceyhan:NNCorrespond2018nnspat.
Each function yields a vector of length \(k\) of the test statistics, \(p\)-values for the corresponding
alternative, null values (i.e., expected values), sample estimates (i.e., observed values) of self entries
in the SCCT or diagonal entries in the NNCT, a \(k \times 2\) matrix of confidence intervals (where each row is the
confidence interval for self entry \(S_i\) in the SCCT or diagonal entry \(N_{ii}\) in the NNCT) and
also names of the test statistics, estimates, null values, the description of the test, and the data
set used.
The null hypothesis is that all \(E[S_i] = E[N_{ii}] = n_i(n_i - 1)/(n - 1)\) where \(n_i\) is the size of class \(i\) and
\(n\) is the data size.
The Znnself functions (i.e., Znnself.ct and Znnself) are different from the Znnref functions
(i.e., Znnref.ct and Znnref) and from Zself.ref functions (i.e., Zself.ref.ct and Zself.ref) and also from
Znnself.sum functions (i.e., Znnself.sum.ct and Znnself.sum).
Znnself functions are testing the self reflexivity at a class-specific level (i.e., for each class) using the
first column in the SCCT, while Zself.ref functions are for testing the self reflexivity for the entire data set
using entry \((1,1)\) in RCT, and Znnref functions are for testing the self reflexivity and mixed non-reflexivity
using the diagonal entries in the RCT, and
Znnself.sum functions are testing the cumulative species correspondence using the sum of the self column (i.e.,
the first column) in the SCCT.