Two functions: Znnsym2cl.ss.ct and Znnsym2cl.ss.
Both functions are objects of class "htest" but with different arguments (see the parameter list below).
Each one performs hypothesis tests of equality of the expected value of the off-diagonal
cell counts (i.e., entries) under RL or CSR in the NNCT for \(k=2\) classes.
That is, each performs Pielou's first type of NN symmetry test which is appropriate
(i.e., have the appropriate asymptotic sampling distribution)
provided that data is obtained by sparse sampling.
(See ceyhan:SWJ-spat-sym2014;textualnnspat for more detail).
Each symmetry test is based on the normal approximation of the difference of the off-diagonal entries
in the NNCT and are due to pielou:1961;textualnnspat.
Each function yields the test statistic, \(p\)-value for the
corresponding alternative, the confidence interval, estimate and null value for the parameter of interest
(which is the difference of the off-diagonal entries in the NNCT), and method and name of the data set used.
The null hypothesis is that \(E(N_{12})=E(N_{21})\) in the \(2 \times 2\) NNCT (i.e., symmetry in the
mixed NN structure).
In the output, the test statistic, \(p\)-value and the confidence interval are valid only
for (properly) sparsely sampled data.
See also
(pielou:1961,ceyhan:SWJ-spat-sym2014;textualnnspat)
and the references therein.