An object of class "Clusters".
Generates n 2D points with k (\(k \ge 2\)) clusters along the horizontal axis
where about \(n/k\) points belongs to each cluster.
If distribution="uniform", the points are uniformly generated in their square
supports where one square is the unit square (i.e., with vertices \((0,0), (1,0), (1,1),(0,1)\)), and
the others are \(d\) units shifted horizontally from each other so that their lower end vertices are
\((j-1)+(j-1) d\) for \(j=1,2,\ldots,k\).
If distribution="bvnormal", the points are generated from the bivariate normal distribution with means equal to the
centers of the above squares (i.e., for each cluster with mean=(j+(j-1)d-1/2,1/2) for \(j=1,2,\ldots,k\)
and the covariance matrix \(sd I_2\), where \(I_2\) is the \(2 \times 2\) identity matrix.
Notice that the clusters are more separated, i.e., generated data indicates more clear clusters as \(d\) increases
in either direction with \(d=0\) indicating one cluster in the data. For a fixed \(d\), when distribution="bvnormal",
the clustering gets stronger if the variance of each component, \(sd^2\), gets smaller, and clustering gets weaker
as the variance of each component gets larger where default is \(sd=1/6\).